Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1249)

Unified Diff: third_party/WebKit/public/web/WebView.h

Issue 2605743002: Use consistent types for ICC profiles (Closed)
Patch Set: No export for static lib Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/web/WebView.h
diff --git a/third_party/WebKit/public/web/WebView.h b/third_party/WebKit/public/web/WebView.h
index eff150990e969caf22731a3ae4d15350351c538f..63e798f316688eab81080c62cfd2ed97b2b6e927 100644
--- a/third_party/WebKit/public/web/WebView.h
+++ b/third_party/WebKit/public/web/WebView.h
@@ -40,6 +40,10 @@
#include "../platform/WebVector.h"
#include "WebWidget.h"
+namespace gfx {
+class ColorSpace;
+}
+
namespace blink {
class WebAXObject;
@@ -318,8 +322,8 @@ class WebView : protected WebWidget {
// level.
virtual void setZoomFactorForDeviceScaleFactor(float) = 0;
- // Set and reset the device color profile.
- virtual void setDeviceColorProfile(const WebVector<char>&) = 0;
+ // Set and reset the device color space.
+ virtual void setDeviceColorSpace(const gfx::ColorSpace&) = 0;
// Resize the view at the same time as changing the state of the top
// controls. If |browserControlsShrinkLayout| is true, the embedder shrunk the

Powered by Google App Engine
This is Rietveld 408576698